;; Generated package description from eev.el  -*- no-byte-compile: t -*-
(define-package "eev" "20260126" "Support for e-scripts (eepitch blocks, elisp hyperlinks, etc)" '((emacs "25.1")) :commit "ffa3b88874d064256c5221d2bbcb1564d901602a" :authors '(("Eduardo Ochs" . "eduardoochs@gmail.com")) :maintainer '("Eduardo Ochs" . "eduardoochs@gmail.com") :keywords '("lisp" "e-scripts") :url "http://anggtwu.net/#eev")
